@@ -259,6 +259,24 @@ def test_zip_store(transform):
         assert zip_transform.handle == HANDLE
 
 
+def test_fallback(transform):
+    target_url = '{}/{}/fallback=cache:12,handle:fallbackHandle/{}'.format(CDN_URL, APIKEY, EXTERNAL_URL)
+    result = transform.fallback(handle='fallbackHandle', cache=12)
+    assert result.url == target_url
+
+
+def test_pdf_info(transform):
+    target_url = '{}/{}/pdfinfo=colorinfo:true/{}'.format(CDN_URL, APIKEY, EXTERNAL_URL)
+    result = transform.pdf_info(colorinfo=True)
+    assert result.url == target_url
+
+
+def test_pdf_convert(transform):
+    target_url = '{}/{}/pdfconvert=pageorientation:landscape/{}'.format(CDN_URL, APIKEY, EXTERNAL_URL)
+    result = transform.pdf_convert(pageorientation='landscape')
+    assert result.url == target_url
+
+
 def quality(transform):
     target_url = '{}/{}/quality=value:75/{}'.format(CDN_URL, APIKEY, EXTERNAL_URL)
     quality = transform.quality(75)
@@ -302,8 +320,8 @@ def test_store(transform):
 
     assert isinstance(store, Filelink)
 
+
 def test_av_convert(transform):
-    url = 'https://cdn.filestack.com/{}'.format(HANDLE)
     @urlmatch(netloc=r'process.filestackapi\.com', method='get', scheme='https')
     def av_convert(url, request):
         return response(200, {'url': url, 'uuid': 'someuuid', 'timestamp': 'sometimestamp'})
@@ -312,10 +330,10 @@ def test_av_convert(transform):
         new_av = transform.av_convert(width=500, height=500)
         assert isinstance(new_av, AudioVisual)
         assert new_av.uuid == 'someuuid'
-        assert new_av.timestamp == 'sometimestamp' 
+        assert new_av.timestamp == 'sometimestamp'
+
 
 def test_debug(transform):
-    url = 'https://process.filestackapi.com/{}'.format(HANDLE)
     @urlmatch(netloc=r'cdn.filestackcontent\.com', method='get', scheme='https')
     def debug(url, request):
         return response(200, {'data': 'somedata'})
